#' Mode of the Input Vector
#'
#' @param y The input vector (factor)
#'
#' @details
#' Returns NA when the input is NULL or NA.
#' When there are ties, the smallest value will be returned.
#'
#' @examples
#' Mode( letters[c(1,2,2,3,3,3,4,4)] )
#' Mode( c(1,2,2,3,3,3,4,4) )
#' Mode( c(1,2,2,3,3,4,4) )
#' Mode( rev(c(1,2,2,3,3,4,4)) ) # same as above.
#'
#' @export
#'

Mode <- function(y) {
  # mode of y
  # Shin-ichi Mayekawa
  # 20230901,1017
  #

  if( is.null(y) || all(is.na(y)) ) md=NA
  else{
    md=names(sort(table(y), decreasing=TRUE))[1]
    if( is.numeric(y) ) md=as.numeric(md)
  }

  return(md)

} # end of Mode



