% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_dt.R
\name{summary_dt}
\alias{summary_dt}
\title{Calculate Summary Statistics of a Decision Tree}
\usage{
summary_dt(
  obj = NULL,
  y = NULL,
  X = NULL,
  yhat = NULL,
  prob = NULL,
  minp = 1e-04,
  nleaf = 0,
  print = 1,
  outpred = 0,
  title = ""
)
}
\arguments{
\item{obj}{The output of DecTree or list of nodes.}

\item{y}{The criterion}

\item{X}{The NEW regressor matrix}

\item{yhat}{predicted value}

\item{prob}{probability of predicted value}

\item{minp}{Minimum value of probability}

\item{nleaf}{# of leaves when obj is not a class DecTree object}

\item{print}{= 0 to suppress the output}

\item{outpred}{= 1 to output the predicted values}

\item{title}{The title string}
}
\value{
A list of the following:
\preformatted{
When \code{y} is categorical
nleaf:  # of leaves
Tab:       cross table: (row=true, col=predicted)
margin :   marginal frequencies
Gini: gini coefficient
mllh: minus log multinomial likelihood
nparam: # of parameters
aic: aic
bic: bic
tprecision: total precision
macroF1: macro F1
weightedF1: # of obs. weighted F1
SCT: a matrix of accuracy, precision, recall, specificity, and F1-score
for each levels of the criterion.

When \code{y} is not categorical
nleaf:  # of leaves
corr:      correlation coefficient
}

When \code{outpred=1}, \code{yhat, prob, Node} will be output.
}
\description{
This function calculates various fit statistics given
the class DecTree object with or without a new regressor matrix. \cr
Japanese help file: \link[lazy.tree]{summary_dt_JPH}
}
\details{
A set of summary statistics will be calculated using a pair of vectors 
\code{(y,yhat)} where \code{y} or \code{yhat} may come from \code{obj}
or given explicitly.

When \code{y} and \code{yhat} are present, it will be used to calculate the
summary statistics regardless of the presence of \code{obj}.

When \code{X} and \code{y} are given, the predicted values will be calculated
by \code{predict_dt} using the rules contained in \code{obj}.

When neither \code{X} nor \code{yhat} are given, \code{yhat} will be
picked up from the node information contained in \code{obj}
without using  \code{predict_dt}.
}
\examples{
Xc <- as.data.frame(cbind(square$c1,square$c2))
res1 <- DecTree( square$Class4, Xc, maxdepth=3, print=1 )
# temp and temp2 should be the same since Xc is not a new regressor matrix.
# No X is given.
temp <- summary_dt( res1, square$Class4, title="square" )
# The same X as contained in obj is given.
temp2 <- summary_dt( res1, square$Class4, Xc, title="square" )
# from y and yhat, no probs
temp22 <- summary_dt( yhat=res1$yhat, y=square$Class4)
# new X is given.
temp3 <- summary_dt( res1, square$Class4[1:10], Xc[1:10,], title="square" )

}
